@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2021/11/4 4:39 下午
-# Copyright (C) 2021 The lesscode Team
 
+import importlib
 import inspect
 import json
 import logging
@@ -11,6 +8,7 @@ import time
 import traceback
 import types
 import uuid
+from contextlib import contextmanager
 from datetime import datetime
 from decimal import Decimal
 from typing import Optional, Awaitable, Any
@@ -25,10 +23,10 @@ from tornado.web import RequestHandler, Application
 
 from lesscode.task.task_helper import TaskHelper
 from lesscode.utils.es_log.record_log import es_record_log
-from lesscode.web.status_code import StatusCode
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.response_result import ResponseResult
 from lesscode.web.router_mapping import RouterMapping
+from lesscode.web.status_code import StatusCode
 
 
 class BaseHandler(RequestHandler):
@@ -97,6 +95,19 @@ class BaseHandler(RequestHandler):
         if data is not None:
             self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
 
+    @contextmanager
+    def make_session(self, pool, **kwargs):
+        pool, _ = options.database[pool]
+        try:
+            sqlalchemy_orm = importlib.import_module("sqlalchemy.orm")
+        except ImportError as e:
+            raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
+        db_session = sqlalchemy_orm.scoped_session(sqlalchemy_orm.sessionmaker(bind=pool, **kwargs))
+        session = db_session()
+        yield session
+        session.commit()
+        session.close()
+
     async def get(self):
         """
         重写父类get请求处理方法，直接调用post方法统一处理
